/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class CBlockComponent extends BaseComponent {

    /**
     * The custom context, which is used in the `template.html` file of the
     * foo-bar component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        const blockLink = this.componentAttributes.href
        const blockLinkClass = blockLink ? 'block-link' : ''
        const iconMap = {}

        iconMap.error = 'exclamation-mark'
        iconMap.pending = 'pause'
        iconMap.running = 'restart'
        iconMap.success = 'check'
        iconMap.approved = 'thumb-up'

        const iconName = this.componentAttributes.icon || iconMap[this.componentAttributes.status]

        return {
            blockLink,
            blockLinkClass,
            iconName,
        }
    }

}

/*
 * Register the event listener for the block link.
 */

document.addEventListener('goToMainLink', event => {
    const blockItem = event.info.component.shadowRoot.getElementById('block-item')
    const mainLink = blockItem.querySelector('#main-link')
    const mainLinkAnchor = mainLink ? mainLink.shadowRoot.querySelector('a') : ''
    const isTextSelected = window.getSelection().toString()

    if (mainLinkAnchor && !isTextSelected)
        mainLinkAnchor.click()
})

/*
 * HTML template & CSS style for c-block.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CBlockComponent.template = `<div class="block-wrapper">
    <div id="block-item" class="block-item \${blockLinkClass}" status="\${attributes.status || ''}" t-on="click:goToMainLink">
        <div class="icon-wrapper">
            <c-icon icon="\${iconName}" status="\${attributes.status ||''}"></c-icon>
        </div>
        <div class="title-wrapper" t-if="attributes.tag || attributes.title">
            <c-tag t-if="attributes.tag">\${attributes.tag}</c-tag>
            <span t-if="attributes.title" class="block-title">\${attributes.title}</span>
        </div>

        <header>
            <slot name="header"></slot>
        </header>

        <main>
            <slot class="main"></slot>
        </main>

        <div class="bottom">
            <slot name="bottom"></slot>
        </div>

        <footer>
            <slot name="footer"></slot>
            <c-link t-if="blockLink" id="main-link" href="\${attributes.href}" tertiary>
                <c-icon icon="arrow-right"></c-icon>
            </c-link>
        </footer>
    </div>
</div>`

CBlockComponent.style = `:host {
    /* Settings for item */
    --initial-item-spacing: 0.75rem;
    --item-spacing-top: calc(var(--initial-item-spacing));
    --item-spacing-right: var(--initial-item-spacing);
    --item-spacing-bottom: var(--initial-item-spacing);
    --item-spacing-left: var(--item-spacing-right);
    --item-spacing: var(--item-spacing-top) var(--item-spacing-right) var(--item-spacing-bottom) var(--item-spacing-left);
    --item-height: auto;
    --item-horizontal-margin-top: calc(var(--gap) / 2);
    --item-horizontal-margin-bottom: var(--item-horizontal-margin-top);

    /* Settings for item elements */
    --icon-column: 3;
    --icon-row: 1;
    --header-column: span 2;
    --tag-header-column: span 3;
    --main-column: span 3;
    --main-row: 3;
    --bottom-column: span 3;
    --bottom-row: 4;
    --border-column: span 3;
    --footer-row: 5;
    --footer-column: span 3;
    --border-row: 6;

    /* Settings for Icon */
    --icon-color: var(--color-content-1);
    --icon-width: auto;
    --icon-height: auto;
    --icon-background: transparent;
    --icon-border-radius: 0;

    /* Settings for timeline */
    --timeline-display: none;
    --timeline-offset: calc(-1 * var(--initial-item-spacing));
    --timeline-height: auto;

    /* Various settings */
    --tag-border-color: var(--border-default-color);
    --tag-border: var(--border-default-width) solid var(--tag-border-color);
    --tag-border-spacing: 0.25rem;
    --code-background: var(--color-ui-2);
    --forms-background: var(--color-ui-2);

    display: block;
    margin-bottom: var(--block-item-spacing, 0);
}

:host(c-block:last-of-type:not([no-background])) {
    --c-block-item-border-bottom: 0;
    --item-border-bottom: 0;
}

/* ============================================================ *
   ELEMENTS
 * ============================================================ */
.block-wrapper {
    height: 100%;
    position: relative;
    display: flex;
}

.block-item {
    --c-icon-color: var(--color-content-1);

    position: relative;
    margin: var(--item-horizontal-margin-top) 0 var(--item-horizontal-margin-bottom);
    display: grid;
    grid-template-columns: var(--grid-columns, auto 1fr auto);
    grid-template-rows: var(--grid-rows, auto auto 1fr auto);
    grid-gap: 0 1rem;
    background: var(--item-background, var(--color-ui-1));
    padding: var(--item-spacing);
    height: var(--item-height);
    width: 100%;
}

.block-item::after {
    display: var(--item-border-display, none);
    position: relative;
    content: "";
    grid-column: var(--border-column);
    grid-row: var(--border-row);
    border-bottom: var(--item-border-bottom, 1px solid var(--color-ui-3));
    padding-top: var(--line-spacing);
}

.block-link {
    position: relative;
    top: 0;
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
    transition-duration: 200ms;
}

.block-link:hover {
    top: -0.25rem;
    cursor: pointer;
}

c-icon {
    --icon-color: inherit;
}

/* -------------------- HEAD -------------------- */
header {
    display: block;
    grid-column: var(--header-column);
    grid-row: var(--header-row);
}

.title-wrapper + header {
    grid-column: var(--tag-header-column);
    border-top: var(--tag-border);
    padding-top: 0.25rem;
    margin-top: 0.125rem;
}

.title-wrapper {
    grid-column: var(--c-block-tag-column);
}

.block-title {
    font-size: 0.875rem;
    text-transform: uppercase;
    letter-spacing: var(--letter-spacing-uppercase);
}

.icon-wrapper {
    position: relative;
    grid-column: var(--icon-column);
    grid-row: var(--icon-row);
}

.icon-wrapper::after {
    display: var(--timeline-display);
    content: "";
    border-left: 1px solid var(--color-ui-3);
    position: absolute;
    height: var(--timeline-height);
    left: calc(var(--block-icon-step-size) / 2);
    top: var(--timeline-offset);
    bottom: 0;
}

.icon-wrapper c-icon {
    display: flex;
    background: var(--icon-background);
    width: var(--icon-width);
    height: var(--icon-height);
    border-radius: var(--icon-border-radius);
    justify-content: center;
    align-items: center;
    flex-shrink: 0;
    z-index: var(--z-index-front);
    position: relative;
}

/* -------------------- MAIN -------------------- */
main {
    grid-column: var(--main-column);
    grid-row: var(--main-row);
    width: 100%;
    display: block;
}

:host([position="center"]) main {
    place-self: center;
    text-align: center;
}

:host([position="middle"]) main {
    place-self: center;
}

/* -------------------- BOTTOM / FOOTER -------------------- */
.bottom {
    grid-column: var(--bottom-column);
    grid-row: var(--bottom-row);
}

footer {
    font-size: 0.875rem;
    grid-column: var(--footer-column);
    grid-row: var(--footer-row);
    opacity: 0.6;
    display: flex;
    align-items: end;
    justify-content: space-between;
}

footer c-link {
    --icon-size: 1rem;
    --icon-color: inherit;

    position: relative;
    margin-left: auto;
    padding-left: var(--item-spacing);
    right: 0;
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
    transition-property: right;
}

footer c-link:hover {
    right: -0.25rem;
}

footer c-icon { /* stylelint-disable-line no-descending-specificity */
    --icon-size: inherit;
}

/* ============================================================ *
   VARIATIONS: TYPES
 * ============================================================ */
/* stylelint-disable no-descending-specificity */

/* -------------------- CARDS  -------------------------------- */
:host([type="cards"]),
:host(:not([type])) {
    --c-block-background: var(--status-color);
    --item-background: var(--status-color);
}

:host([type="cards"]) [status]:not([status=""]),
:host(:not([type])[status]:not([status=""])) {
    --icon-color: var(--color-100);
}

:host([type="cards"][status]),
:host(:not([type])[status]) {
    --color-headings: var(--color-neutral-100);
    --table-border-color: var(--color-neutral-70);
    --tag-border-color: var(--color-neutral-70);

    color: var(--color-neutral-100);
}

/* -------------------- LIST  / TIMELINE ----------------------- */
:host([type="list"]),
:host([type="timeline"]) {
    --tag-border: 0;
    --tag-border-spacing: 0;
    --item-border-display: block;
}

:host([type="list"]) [status]:not([status=""]) {
    --icon-color: var(--status-color);
}

:host([type="list"]:not(:first-of-type)),
:host([type="timeline"]:not(:first-of-type)) {
    --item-spacing-top: calc(var(--initial-item-spacing) * 0.25);
    --item-horizontal-margin-top: 0;
}

:host([type="list"]:not(:last-of-type)),
:host([type="timeline"]:not(:last-of-type)) {
    --item-spacing-bottom: calc(var(--initial-item-spacing) * 0.25);
    --line-spacing: 0.5rem;
    --item-horizontal-margin-bottom: 0;
}

:host:host([type="list"]),
:host:host([type="timeline"]) {
    --block-ratio-display: none;
}

/* -------------------- TIMELINE  ----------------------------- */
:host([type="timeline"]) {
    --grid-columns: minmax(8rem, 1fr) auto 4fr;
    --c-block-tag-column: 3;
    --icon-column: 2;
    --icon-row: 1 / span var(--border-row);
    --c-block-header-column: 3 / 3;
    --header-row: 1 / 3;
    --header-column: 1;
    --main-row: initial;
    --bottom-row: 4;
    --line-spacing: var(--initial-item-spacing);
    --item-spacing-bottom: 0;
    --tag-header-column: 1;

    /* Icon Settings */
    --block-icon-step-size: 2rem;
    --icon-width: var(--block-icon-step-size);
    --icon-height: var(--block-icon-step-size);
    --icon-background: var(--status-color, var(--color-c-timeline-background-default));
    --icon-border-radius: 100%;
    --icon-color: var(--color-neutral-90);
    --timeline-display: block;
    --item-top-value: 0;
    --item-bottom-value: 0;
    --item-height-value: 100%;
}

:host(c-block:first-of-type[type="timeline"]) {
    --item-top-value: var(--initial-item-spacing);
    --timeline-offset: var(--initial-item-spacing);
}

:host(c-block:last-of-type[type="timeline"]) {
    --item-bottom-value: auto;
    --item-height-value: var(--initial-item-spacing);
    --timeline-height: calc(2 * var(--initial-item-spacing));
}

:host(c-block:first-of-type[type="timeline"]:last-of-type[type="timeline"]) {
    --timeline-display: none;
}

:host([type="timeline"]) header {
    text-align: right;
}

/* ============================================================ *
   VARIATIONS
 * ============================================================ */

/* -------------------- BACKGROUNDS -------------------- */
:host([no-background]) {
    --item-background: transparent;
    --item-spacing: 0 0 var(--initial-item-spacing);
    --code-background: var(--color-ui-1);
}

:host(c-block:last-of-type[no-background]:not([status])) {
    --item-spacing: 0;
}

/* -------------------- RATIOS -------------------- */
.block-wrapper::before {
    display: var(--block-ratio-display, none);
    float: left;
    width: 1px;
    height: 0;
    margin-left: -1px;
    content: "";
    padding-top: var(--block-ratio, 0);
}

:host([ratio]) {
    --block-ratio-display: block;
}

:host([ratio="1x1"]) {
    --block-ratio: 100%;
}

:host([ratio="4x3"]) {
    --block-ratio: 75%;
}

:host([ratio="3x4"]) {
    --block-ratio: 133%;
}

:host([ratio="2x1"]) {
    --block-ratio: 50%;
}

:host([ratio="1x2"]) {
    --block-ratio: 200%;
}

/* -------------------- STATUS MODIFIERS -------------------- */
:host([type="cards"]) [status]:not([status=""]) c-icon,
:host(:not([type])[status]:not([status=""])) c-icon {
    --color: var(--color-100);
}

:host(:is([type="cards"][status],:not([type])[status]):is([status*="error"], [status*="success"], [status*="pending"], [status*="running"], [status*="approved"])) {
    --color-headings: var(--color-neutral-100);
    --table-border-color: var(--color-neutral-70);
    --tag-border-color: var(--color-neutral-70);
    --code-background: var(--color-neutral-30);
    --item-background: var(--status-color);
    --item-spacing: var(--item-spacing-top) var(--item-spacing-right) var(--item-spacing-bottom) var(--item-spacing-left);
    --icon-color: var(--color-100);

    color: var(--color-neutral-100);
}

:host([status*="error"][status*="error"]) {
    --status-color: var(--color-status-error);
}

:host([status*="success"][status*="success"]) {
    --status-color: var(--color-status-success);
}

:host([status*="pending"][status*="pending"]) {
    --status-color: var(--color-status-hint-3);
}

:host([status*="running"][status*="running"]) {
    --status-color: var(--color-status-info);
}

:host([status*="approved"][status*="approved"]) {
    --status-color: var(--color-status-info-3);
}
/* stylelint-enable no-descending-specificity */`
/* eslint-enable max-len */

/*
 * Define web component tag for c-block.
 */

window.customElements.define('c-block', CBlockComponent)

/*
 * Default export the concrete class for c-block.
 */

export default CBlockComponent
