/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import ComponentEvent from '../event.js?v=1.12.1'

class CButtonComponent extends BaseComponent {

    /**
     * Map the data from the data object and the custom component
     * attribues and set them as attributes on the element
     */

    render() {
        super.render()

        const buttonElement = this.shadowRoot.getElementById('button')
        const [slotElement] = this.shadowRoot.querySelector('slot').assignedNodes()

        if (!slotElement && this.componentAttributes.icon)
            buttonElement.classList.add('icon-only')

        if (this.componentAttributes.submit) {
            buttonElement.addEventListener('click', () => {
                this.dispatchEvent(new ComponentEvent('submitForm'))
            })
        }

        if (this.componentAttributes.href)
            buttonElement.setAttribute('href', this.componentAttributes.href)
    }

}

/*
 * HTML template & CSS style for c-button.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CButtonComponent.template = `<a id="button" role="button">
    <slot><span t-if="!attributes.icon">this is an anchor styled as button</span></slot>
    <c-icon t-if="attributes.icon" icon="\${attributes.icon}" size="\${attributes.size}"></c-icon>
</a>`

CButtonComponent.style = `:host {
    display: inline-flex;

    --button-text: var(--color-interactive-text);
    --button-background: var(--color-interactive-area);
    --button-border-color: var(--color-interactive-area);
    --button-min-width: 7rem;
    --button-padding: calc(0.25rem - var(--border-default-width)) 1rem;
    --button-icon-spacing-outer: -0.5rem;
    --button-icon-spacing-inner: 1rem;
    --button-icon-margin: 0 var(--button-icon-spacing-inner) 0 var(--button-icon-spacing-outer);
}

a {
    display: flex;
    align-items: center;
    background: var(--button-background);
    color: var(--button-text);
    border: var(--border-default-width) solid var(--button-border-color);
    padding: var(--button-padding);
    font-size: 1rem;
    text-transform: uppercase;
    font-weight: 500;
    text-decoration: none;
    text-align: center;
    letter-spacing: var(--letter-spacing-uppercase);
    line-height: var(--line-height-base);
    border-radius: var(--border-radius);
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
    width: var(--button-width, 100%);
    justify-content: center;
    box-sizing: border-box;
    min-width: var(--button-min-width);
}

:host([secondary]) {
    --button-text: var(--color-interactive-button-text);
    --button-background: transparent;
    --button-border-color: var(--color-interactive-button-text);
}

:host([tertiary]) {
    --button-text: var(--color-interactive-button-text);
    --button-background: transparent;
    --button-border-color: transparent;
}

c-icon {
    --icon-color: var(--button-text);

    line-height: 100%;
    align-self: center;
    order: var(--button-icon-order, -1);
    margin: var(--button-icon-margin);
}

.icon-only {
    --button-min-width: 0;
    --button-padding: calc(0.25rem - var(--border-default-width));
    --button-icon-margin: 0;
}

:host([icon-position="right"]) {
    --button-icon-margin: 0 var(--button-icon-spacing-outer) 0 var(--button-icon-spacing-inner);
    --button-icon-order: 0;
}

/* -------------------- VARIATION -- full width button -------------------- */
:host([full-width]) {
    width: 100%;
}

/* -------------------- VARIATION -- higher button -------------------- */
:host([padded]) {
    --button-padding: calc(0.75rem - var(--border-default-width)) 4rem;
    --button-min-width: calc(8rem + var(--button-min-width));
}

:host([padded]) .icon-only {
    --button-min-width: 0;
    --button-padding: calc(0.75rem - var(--border-default-width)) 1rem;
}

/* -------------------- VARIATION -- form label left -------------------- */
:host([label-position="left"]) {
    display: flex;
}

:host([label-position="left"])::before {
    content: "";
    flex-basis: calc(var(--forms-label-left-label-size) + var(--forms-label-left-label-spacing));
}

:host([label-position="left"]) a {
    --button-width: 50%;

    flex: 1;
}

/* -------------------- STATES -------------------- */
/* stylelint-disable no-descending-specificity */
a:hover,
[state="hover"] a {
    --button-text: var(--color-interactive-text);
    --button-background: var(--color-interactive-hover);
    --button-border-color: var(--color-interactive-hover);

    cursor: pointer;
    box-shadow: var(--box-shadow-default);
}

:host([disabled]) a,
:host([action][disabled]) a:hover {
    --button-background: var(--color-disabled);
    --button-text: var(--color-disabled-text);

    cursor: not-allowed;
    border-color: var(--color-disabled);
    box-shadow: none;
}

:host([disabled][secondary]) a,
:host([disabled][secondary]) a:hover {
    --button-background: transparent;
    --button-text: var(--color-disabled);

    opacity: 0.5;
}

:host([action="confirmation"]) a:hover,
:host([action="confirmation"]):host([state="hover"]) a {
    --button-background: var(--color-status-success);
    --button-border-color: var(--color-status-success);
}

:host([action="attention"]) a:hover,
:host([action="attention"]):host([state="hover"]) a {
    --button-background: var(--color-status-error);
    --button-border-color: var(--color-status-error);
}

a:focus,
:host([state="focus"]) a {
    outline: var(--forms-outline);
    outline-offset: var(--forms-outline-offset);
}

:host([state="active"]) a,
:host([state="focus"]) a:active,
a:active {
    --button-background: var(--color-interactive-active);
    --button-border-color: var(--color-interactive-area);

    outline: none;
}
/* stylelint-enable no-descending-specificity */`
/* eslint-enable max-len */

/*
 * Define web component tag for c-button.
 */

window.customElements.define('c-button', CButtonComponent)

/*
 * Default export the concrete class for c-button.
 */

export default CButtonComponent
