/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import {ValidationError} from '../errors.js?v=1.12.1'

class CHeadingComponent extends BaseComponent {

    /**
     * Replace the heading element `h1` with the level defined in the component
     * attributes.
     *
     * @param   {HTMLElement}   element     The HTML template element
     *
     * @return  {HTMLElement}               The rendered HTML element
     */

    renderElement(element) {
    if (element.tagName === 'H1') {
        const level = this.componentAttributes.level || ''

        if (!level.match(/^[1-6]$/u))
            throw new ValidationError(`Missing or wrong level "${level}" for heading defined`)

        const newElement = document.createElement(`h${level}`)

        for (const attr of element.attributes) 
            newElement.setAttribute(attr.name, attr.value)

        while (element.firstChild) 
            newElement.appendChild(element.firstChild)

        return super.renderElement(newElement)
    }

    return super.renderElement(element)
}


}

/*
 * HTML template & CSS style for c-heading.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CHeadingComponent.template = `<div>
    <h1>
      <slot></slot>
    </h1>
</div>`

CHeadingComponent.style = `:host {
    display: block;
}

h1,
h2,
h3,
h4,
h5,
h6 {
    position: relative;
    margin: 0;
    font-size: 1rem;
    line-height: var(--line-height-base);
    font-weight: 700;
    text-transform: var(--text-transform-heading);
    letter-spacing: var(--letter-spacing-heading);
    color: var(--color-headings);
    transition: var(--transition-property) var(--forms-transition-duration) var(--forms-transition-timing-function);
}

h1,
::slotted(h1) {
    font-weight: 300;
    font-size: 1.5rem;
    line-height: 2rem;
}

h2 {
    font-weight: 700;
    font-size: 1.25rem;
    line-height: 2rem;
}

h3 {
    font-weight: 500;
    font-size: 1rem;
    line-height: 1.5rem;
}

h4 {
    font-weight: 500;
    font-size: 0.75rem;
    line-height: 1.5rem;
    color: var(--color-ui-4);
    letter-spacing: 0.08rem;
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-heading.
 */

window.customElements.define('c-heading', CHeadingComponent)

/*
 * Default export the concrete class for c-heading.
 */

export default CHeadingComponent
