/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import {getPath} from '../utils.js?v=1.12.1'

class CIconComponent extends BaseComponent {

    /**
     * The icon path, which is used in the `template.html` file of the
     * c-icon component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        const iconName = this.componentAttributes.icon || 'check'

        const iconFile = getPath(`assets/icons/${iconName}.svg`)

        return {
            iconFile,
        }
    }

    render() {
        super.render()

        this.setInlineSVG()
    }

    /**
     * Sets the icon as inline svg.
     */

    setInlineSVG() {
        const iconName = (this.componentAttributes.icon || 'check').trim()
        if (iconName === 'undefined')
            return

        const iconFile = getPath(`assets/icons/${iconName}.svg`)
        const divElement = this.shadowRoot.getElementById('icon')
        divElement.innerHTML = ''

        fetch(iconFile)
            .then(response => response.text())
            .then(svg => divElement.insertAdjacentHTML('afterbegin', svg))
    }

}

/*
 * HTML template & CSS style for c-icon.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CIconComponent.template = `<div id="icon" class="icon-wrapper">

</div>`

CIconComponent.style = `:host {
    --icon-color: var(--color-content-1);
    --icon-size: var(--default-icon-size);
}

:host(c-icon) { /* stylelint-disable-line selector-type-no-unknown */
    display: inline-flex;
    vertical-align: text-bottom;
}

div {
    display: inline-block;
}

svg {
    display: block; /* Removes additional letter spacing around element. */
    pointer-events: none; /* Prevents IE11 from swallowing events. */
    vertical-align: middle;
    height: var(--icon-size);
    width: var(--icon-size);
    stroke: var(--icon-color);
    stroke-width: var(--stroke-width);
}

path,
rect,
circle {
    fill: var(--icon-color);
    transition: all var(--transition-duration) var(--transition-timing-function);
}

/* -------------------- SIZES -------------------- */
:host([size='md']) {
    --icon-size: 1.5rem;
    --stroke-width: 1px;
}

:host([size='lg']) {
    --icon-size: 3rem;
    --stroke-width: 1px;
}

:host([size='xl']) {
    --icon-size: 5rem;
    --stroke-width: 0;
}

/* -------------------- COLORS -------------------- */
:host([status='success']) {
    --icon-color: var(--color-status-success);
}

:host([status='warning']) {
    --icon-color: var(--color-status-warning);
}

:host([status='error']) {
    --icon-color: var(--color-status-error);
}

:host([status='info']) {
    --icon-color: var(--color-status-info);
}

:host([status='pending']) {
    --icon-color: var(--color-status-hint-3);
}

:host([status='progress']) {
    --icon-color: var(--color-status-info);
}

:host([status='approved']) {
    --icon-color: var(--color-status-info-3);
}

/* -------------------- MISSING FILE -------------------- */
.icon-wrapper h1,
.icon-wrapper p {
    display: none;
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-icon.
 */

window.customElements.define('c-icon', CIconComponent)

/*
 * Default export the concrete class for c-icon.
 */

export default CIconComponent
