/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import theme from '../theme.js?v=1.12.1'

class CImageComponent extends BaseComponent {

    /**
     * The custom context, which is used in the `template.html` file of the
     * c-image component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        return {
            'src': this.src,
        }
    }

    get src() {
        const srclight = this.componentAttributes.srclight || this.componentAttributes.src
        const srcdark = this.componentAttributes.srcdark || this.componentAttributes.src

        return theme.currentMode === 'light' ? srclight : srcdark
    }

    render() {
        super.render()

        document.addEventListener('switchThemeMode', () => {
            this.shadowRoot.getElementById('image').setAttribute('src', this.src)
        })
    }

}

/*
 * HTML template & CSS style for c-image.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CImageComponent.template = `<div class="image-wrapper">
    <img id="image"
         src="\${src || 'https://via.placeholder.com/100x100'}"
         alt="\${attributes.alt || ''}"
         width="\${attributes.width || ''}"
         height="\${attributes.height || ''}"
    >
</div>`

CImageComponent.style = `:host {
    display: block;
    height: 100%;
    overflow: hidden;
}

:host([inline]) {
    display: inline-block;
}

.image-wrapper {
    height: 100%;
    width: 100%;
}

img {
    border-style: none; /* Remove the border on images within links in IE 10-. */
    display: block;
    height: auto;
    max-height: 100%;
    max-width: 100%;
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-image.
 */

window.customElements.define('c-image', CImageComponent)

/*
 * Default export the concrete class for c-image.
 */

export default CImageComponent
