/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import ComponentEvent from '../event.js?v=1.12.1'

class CInputComponent extends BaseComponent {

    /**
     * The data of this component, which should be transferred when a form is
     * submitted.
     *
     * @return  {Object}    The form data
     */

    get formData() {
        return {
            [this.componentAttributes.name]: this.shadowRoot.querySelector('input').value,
        }
    }

    /**
     * The custom context, which is used in the `template.html` file of the
     * c-input component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        const data = {...this.componentAttributes, ...this.data.inputObject}
        const labelInside = data && data['label-position'] === 'inside'
        const labelPosition = data['label-position']

        let state =  ''
        state += data.error ? 'error ' : ''
        state += data.disabled ? 'disabled ' : ''
        state += data.required ? 'required ' : ''

        return {
            data,
            labelInside,
            labelPosition,
            state,
        }
    }

    /**
     * Reflect the component attributes to the input element of this component.
     * Also submit the form when the "Enter" key is pressed.
     */

    render() {
        super.render()

        this.reflectComponentAttributes(
            [
                'disabled',
                'name',
                'placeholder',
                'required',
                'title',
                'value',
            ],
            this.shadowRoot.querySelectorAll('input'),
        )

        // Send form when "Enter" key is pressed.
        this.shadowRoot.querySelector('input').addEventListener('keyup', event => {
            const enterKey = 13
            if (event.keyCode === enterKey)
                this.dispatchEvent(new ComponentEvent('submitForm'))
        })
    }

}

/*
 * HTML template & CSS style for c-input.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CInputComponent.template = `<label class="\${state}">
    <c-label t-if="data.label && !labelInside"
             label-position="\${labelPosition}"
             required="\${data.required}"
             class="label-text">
        \${data.label}
    </c-label>

    <div class="content-wrapper">
        <div class="input-wrapper">
            <c-label t-if="data.label && labelInside"
                     class="label-text"
                     label-position="\${labelPosition}"
                     required="\${data.required}">
                \${data.label}
            </c-label>

            <input type="\${data.type || 'text'}" t-on="change:updateFormData">
        </div>

        <div t-if="attributes.help" class="help">
            \${attributes.help}
        </div>
        
        <slot name="help" class="help"></slot>

        <div t-if="data.error" class="error-text">
            \${data.error}
        </div>
    </div>
</label>`

CInputComponent.style = `/* ============================================================ *
   GENERIC
 * ============================================================ */

/* -------------------- RESETS -------------------- */
*,
::before,
::after {
    box-sizing: border-box;
}

/*
 * Change the cursor on disabled, not-editable, or otherwise
 * inoperable elements in all browsers (opinionated).
 */

[aria-disabled="true"],
[disabled] {
    cursor: not-allowed;
}

/* ============================================================ *
   ELEMENTS
 * ============================================================ */

:host {
    --input-spacing-right: 0;

    display: block;
    width: 100%;
    margin-bottom: var(--forms-margin);
}

:host([type="hidden"]) {
    display: none;
}

c-label {
    display: flex;
}

.content-wrapper {
    display: flex;
    flex-flow: column;
}

.input-wrapper {
    position: relative;
    width: 100%;
    display: flex;
    flex-wrap: wrap;
    padding: var(--forms-padding);
    padding-right: calc(var(--forms-padding-horizontal) + var(--input-spacing-right));
    min-height: var(--forms-height);
    border-style: var(--forms-border-style);
    border-color: var(--forms-border-color);
    border-width: var(--forms-border-width);
    border-radius: var(--forms-border-radius);
    margin-top: var(--forms-border-shift);
    outline: 0;
    background: var(--forms-background);
    color: var(--color-content-2);
    transition: border-color var(--forms-transition-duration) var(--forms-transition-timing-function);
}

input {
    width: 100%;
    margin: 0;
    padding: 0;
    border: 0;
    outline: 0;
    font-family: inherit;
    font-size: 100%;
    line-height: var(--line-height-base);
    color: inherit;
    background: transparent;
}

.error-text {
    font-size: var(--forms-error-font-size);
    padding: 0 var(--forms-padding-horizontal);
}

.help {
    font-size: var(--forms-help-font-size);
    color: var(--forms-color-help);
    font-style: var(--forms-help-font-style);
    padding: 0 var(--forms-padding-horizontal);
    display: inline;
}

/* Chrome date & time icons */
::-webkit-calendar-picker-indicator { /* stylelint-disable-line no-descending-specificity */
    filter: var(--calender-indicator-filter);
}

/* -------------------- VARIATION -- label-left -------------------- */
:host([label-position="left"]) label,
:host([label-position="left"]) c-label {
    display: flex;
    flex-wrap: wrap;
    align-items: baseline;
    gap: 0 var(--forms-label-left-label-spacing);
}

:host([label-position="left"]) .content-wrapper {
    flex-basis: var(--forms-label-left-input-size);
    flex-grow: 1000;
}

:host([label-position="left"]) .label-text {
    flex-basis: var(--forms-label-left-label-size);
}

/* -------------------- VARIATION -- label-inside -------------------- */
:host([label-position="inside"]) .input-wrapper {
    display: flex;
    align-items: baseline;
    gap: 0 var(--forms-label-left-label-spacing);
}

:host([label-position="inside"]) .label-text {
    flex-basis: var(--forms-label-left-label-size);
}

:host([label-position="inside"]) input {
    width: 12rem;
    flex-grow: 1000;
}

/* -------------------- VARIATION -- file-upload -------------------- */
:host([type="file"]) .input-wrapper {
    --button-text: var(--color-interactive-text);
    --button-background: var(--color-interactive-area);
    --button-border-color: var(--color-interactive-area);
    --button-padding: 0 1em;
    --button-shadow: none;
}

:host([type="file"]) ::file-selector-button {
    background: var(--button-background);
    color: var(--button-text);
    border: var(--border-default-width) solid var(--button-border-color);
    padding: var(--button-padding);
    text-transform: uppercase;
    font-weight: 500;
    text-decoration: none;
    text-align: center;
    letter-spacing: var(--letter-spacing-uppercase);
    line-height: var(--line-height-base);
    border-radius: var(--border-radius);
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
    box-shadow: var(--button-shadow);
}

:host([type="file"]) .input-wrapper:hover {
    --button-text: var(--color-interactive-text);
    --button-background: var(--color-interactive-hover);
    --button-border-color: var(--color-interactive-hover);
    --button-shadow: var(--box-shadow-default);

    cursor: pointer;
}

/* -------------------- STATES -------------------- */
/* stylelint-disable no-descending-specificity */
.input-wrapper:hover {
    border-color: var(--forms-border-color-hover);
}

.input-wrapper:focus-within {
    outline: var(--forms-outline);
    outline-offset: var(--forms-outline-offset);
}

/* Error */
.error .label-text,
.error .input-wrapper::after,
.error-text {
    color: var(--color-status-error);
}

.error .input-wrapper {
    border-color: var(--color-status-error);
    padding-right: 1rem;
}

.error .input-wrapper::after {
    content: "!";
    position: absolute;
    right: var(--forms-padding-horizontal);
    font-weight: 900;
}

/* Disabled */
:host([disabled]) {
    color: var(--forms-color-disabled);
}

:host([disabled]) .input-wrapper {
    border-color: var(--forms-border-color-disabled);
    background: var(--forms-background-disabled);
    padding: var(--forms-padding-disabled);
}

:host([disabled]) .input-wrapper:hover {
    border-color: var(--forms-border-color-disabled);
}
/* stylelint-enable no-descending-specificity */`
/* eslint-enable max-len */

/*
 * Define web component tag for c-input.
 */

window.customElements.define('c-input', CInputComponent)

/*
 * Default export the concrete class for c-input.
 */

export default CInputComponent
