/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Concrete web component class for c-link.
 * This is automatically generated by the builder.
 */

class CLinkComponent extends BaseComponent {}

/*
 * HTML template & CSS style for c-link.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CLinkComponent.template = `<a href="\${attributes.href || '#'}"
   target="\${attributes.target || '_self'}"
   title="\${attributes.title || ''}"
>
    <span t-if="attributes.type === 'secondary'" class="secondary-link-icon">
        <c-icon icon="arrow-right"></c-icon>
    </span>

    <slot>This is an anchor</slot>

    <span t-if="attributes.external">
        <c-icon icon="external"></c-icon>
    </span>
</a>`

CLinkComponent.style = `:host {
    --link-border-size: 2px;
    --link-border-display: 'block';
    --link-padding: 0;
    --color: var(--color-content-1);
    --icon-color: var(--color);

    display: inline-flex;
    max-height: 100%;
}

:host([full-width]) {
    width: 100%;
    text-align: center;
}

/* ============================================================ *
   ELEMENTS
 * ============================================================ */

a {
    position: relative;
    width: 100%;
    display: inline-block;
    padding: var(--link-padding);
    background-color: transparent; /* Remove the gray background on active links in IE 10. */
    letter-spacing: var(--letter-spacing, 0.05em);
    text-decoration: none;
    color: var(--color);
    font-weight: var(--font-weight, 600);
    border: 0;
    border-bottom: var(--link-border-size, 1px) solid var(--color-interactive-link-border);
    margin-bottom: calc(-1 * var(--link-border-size));
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
}

a::after {
    display: var(--link-border-display);
    content: "";
    position: absolute;
    width: var(--link-border-width, 0);
    left: 0;
    bottom: calc(var(--link-border-size) * -1);
    border-bottom: var(--link-border-size) solid var(--link-border-color, var(--color-interactive-button-text));
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
}

c-icon {
    --icon-color: inherit;
}

/* -------------------- LINK ICON -------------------- */
.secondary-link-icon {
    position: relative;
    margin-right: 0.75rem;
    left: var(--link-icon-position-left, 0);
    transition: all var(--transition-duration-links) var(--transition-timing-function);
}

/* ============================================================ *
   STATES
 * ============================================================ */

a:hover,
:host([state="hover"]) {
    --link-border-width: 100%;
    --link-icon-position-left: 0.25rem;
}

a:focus,
:host([state="focus"]) {
    --link-border-width: 100%;
    --link-icon-position-left: 0.25rem;
}

a:active,
:host([state="active"]) {
    --link-border-width: 100%;
    --link-border-color: var(--color-interactive-link-active);
    --link-icon-position-left: 0.5rem;
}

/* ============================================================ *
   VARIATIONS
 * ============================================================ */

/* -------------------- EXTERNAL -------------------- */
:host([external]) {
    display: inline-flex;
    align-items: center;
}

:host([external]) c-icon {
    --icon-size: 1em;

    margin: 0 0 0 0.5rem;
    vertical-align: middle;
}

/* -------------------- SECONDARY -------------------- */
:host([type="secondary"]) {
    --link-border-display: none;
    --link-border-size: 0;
}

:host([type="secondary"]) a:hover,
:host([type="secondary"][state="hover"]) {
    --color: var(--color-interactive-link-hover);
    --icon-color: var(--color);
}

:host([type="secondary"]) a:focus,
:host([type="secondary"][state="focus"]) {
    --color: var(--color-interactive-link-hover);
}

:host([type="secondary"]) a:active,
:host([type="secondary"][state="active"]) {
    --color: var(--color-interactive-link-active);
}

/* -------------------- TERTIARY -------------------- */
:host([type="tertiary"]) { /* stylelint-disable-line no-descending-specificity */
    --link-border-size: 0;
    --link-border-display: none;
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-link.
 */

window.customElements.define('c-link', CLinkComponent)

/*
 * Default export the concrete class for c-link.
 */

export default CLinkComponent
