/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class CNavigationOverlayComponent extends BaseComponent {

    render() {
        super.render()

        document.addEventListener('toggleOverlay', () => {
            this.toggleAttribute('overlayVisible')
        })
    }

}

/*
 * HTML template & CSS style for c-navigation-overlay.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CNavigationOverlayComponent.template = `<div id="hybridOverlay" type="\${attributes.type || ''}" class="overlay-wrapper">

    <!-- OVERLAY CONTENT-->
    <div class="content-wrapper">

        <!-- HYBRID CONTENT (visible with and without active overlay, but styled different) -->
        <div class="content-hybrid">
            <slot>[ HYBRID CONTENT ]</slot>
        </div>

        <!-- OVERLAY CONTENT (only visible in active overlay) -->
        <div class="content-overlay">
            <slot name="overlay-content">[ OVERLAY CONTENT ]</slot>
        </div>

    </div>

    <!-- OVERLAY BUTTON TOGGLE -->
    <span id="overlayToggle" class="toggle-button" t-on="click:toggleOverlay">
        <span class="toggle-icon"></span>
    </span>

</div>`

CNavigationOverlayComponent.style = `:host {
    display: block;
    position: relative;
    z-index: var(--z-index-front);

    /* TODO: move this settings to the base.css */
    --link-color-active: var(--color-interactive-area);
    --button-line-color: var(--color-content-1);
    --overlay-spacing: var(--site-spacing-vertical);
}

/* Show overlay button for mobile screens and hide hybrid content */
@media screen and (width <= 768px) {
    :host {
        --hybrid-content-display: none;
        --overlay-toggle-display: block;
    }
}

:host([overlayVisible]) {
    --overlay-content-display: block;
    --hybrid-content-display: block;
    --overlay-toggle-display: block;
}

:host([overlayToggleVisible]) {
    --overlay-toggle-display: block;
}

/* -------------------- OVERLAY BUTTON -------------------- */
.toggle-button {
    --button-line-color: var(--color-content-1);
    --button-line-width: 1.5rem;
    --button-line-height: 2px;
    --button-line-offset: 0.5rem;
    --button-line-padding-horizontal: 1rem;
    --button-line-padding-vertical: 0.5rem;
    --button-line-border-radius: 2px;

    display: var(--overlay-toggle-display, none);
    position: relative;
    align-self: baseline;
    padding: var(--button-line-padding-horizontal) var(--button-line-padding-vertical);
    cursor: pointer;
    user-select: none;
}

.toggle-icon,
.toggle-icon::before,
.toggle-icon::after {
    --transition-property: all;

    position: relative;
    display: block;
    height: var(--button-line-height);
    width: var(--button-line-width);
    border-radius: var(--button-line-border-radius);
    background-color: var(--button-line-color);
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
}

.toggle-icon::before,
.toggle-icon::after {
    --transform-size: calc(var(--button-line-offset) * 0.75);
    --transform: inherit;
    --top: auto;

    content: "";
    position: absolute;
    transform: var(--transform);
    top: var(--top);
}

.toggle-icon::before {
    --top: calc(-1 * var(--button-line-offset));
}

.toggle-icon::after {
    --top: var(--button-line-offset);
}

.toggle-button:hover {
    --button-line-color: var(--link-color-active);
}

:host([overlayVisible]) .toggle-icon {
    background: transparent;
}

:host([overlayVisible]) .toggle-icon::before {
    --transform: rotate(45deg);
    --top: 0;
}

:host([overlayVisible]) .toggle-icon::after {
    --transform: rotate(-45deg);
    --top: 0;
}

/* -------------------- OVERLAY -------------------- */
.overlay-wrapper {
    --transition-property: background;

    display: flex;
    gap: var(--gap);
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
}

:host([overlayVisible]) .overlay-wrapper {
    position: fixed;
    left: 0;
    top: 0;
    overflow: auto;
    height: 100vh;
    width: calc(100% - 2 * var(--site-spacing-vertical));
    padding: var(--overlay-spacing);
    background: var(--color-ui-1);
}

.content-wrapper {
    flex: 1;
    gap: var(--gap);
}

/* -------------------- HYBRID CONTENT -------------------- */
.content-hybrid {
    display: var(--hybrid-content-display);
}

/* -------------------- OVERLAY CONTENT -------------------- */
.content-overlay {
    display: var(--overlay-content-display, none);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-navigation-overlay.
 */

window.customElements.define('c-navigation-overlay', CNavigationOverlayComponent)

/*
 * Default export the concrete class for c-navigation-overlay.
 */

export default CNavigationOverlayComponent
