/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class CNotificationComponent extends BaseComponent {

    /**
     * The custom context, which is used in the `template.html` file of the
     * foo-bar component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        const notificationType = this.componentAttributes.type || 'info'
        const statusIconMap = {}

        statusIconMap.info = 'info'
        statusIconMap.error = 'exclamation-mark'
        statusIconMap.success = 'check'
        statusIconMap.warning = 'flash'

        const statusIcon = statusIconMap[notificationType]
        const iconName = statusIcon

        return {
            iconName,
        }
    }

}

/*
 * HTML template & CSS style for c-notification.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CNotificationComponent.template = `<div class="notification">
    <div class="icon-wrapper">
        <c-icon icon="\${iconName}"></c-icon>
    </div>
    <div>
        <header>
            <strong><slot name="title"></slot></strong>
        </header>

        <slot>\${attributes.type || 'info'}</slot>
    </div>
</div>`

CNotificationComponent.style = `:host {
    --icon-size: 1rem;
    --icon-padding: 1rem;

    width: 100%;
    display: block;
}

/* ============================================================ *
   ELEMENTS
 * ============================================================ */

.notification {
    display: flex;
    align-items: center;
    padding: 0.75rem;
    border: var(--border-default-width) solid var(--notification-status-color, var(--border-default-color));
    border-radius: var(--border-radius);
    margin: 0 -1rem;
}

:host([type="success"]) .notification {
    border-color: var(--color-status-success);
}

:host([type="info"]) .notification {
    border-color: var(--color-status-info);
}

:host([type="warning"]) .notification {
    border-color: var(--color-status-warning);
}

:host([type="error"]) .notification {
    border-color: var(--color-status-error);
}

.icon-wrapper {
    --size: calc(var(--icon-size) + var(--icon-padding));

    flex: 0 0  auto;
    display: flex;
    justify-content: center;
    align-items: center;
    margin-right: 1rem;
    width: var(--size);
    height: var(--size);
    border-radius: 100%;
    padding: 0.25rem;
    background: var(--notification-status-color, var(--color-status-info));
}

c-icon {
    --icon-color: var(--color-neutral-100);
    --icon-size: 1.5rem;

    width: var(--icon-size);
    height: var(--icon-size);
}

/* ============================================================ *
   VARIATIONS
 * ============================================================ */
:host([type="success"]) {
    --notification-status-color: var(--color-status-success);
}

:host([type="info"]) {
    --notification-status-color: var(--color-status-info);
}

:host([type="warning"]) {
    --notification-status-color: var(--color-status-warning);
}

:host([type="error"]) {
    --notification-status-color: var(--color-status-error);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-notification.
 */

window.customElements.define('c-notification', CNotificationComponent)

/*
 * Default export the concrete class for c-notification.
 */

export default CNotificationComponent
