/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class CSectionComponent extends BaseComponent {

    /**
     * Reflect the component attributes to the input element of this component.
     * Also submit the form when the "Enter" key is pressed.
     */

    render() {
        super.render()

        const slotted = this.shadowRoot.querySelector('slot:not([name="title"])')
        const slotElements = slotted.assignedNodes().filter(node => node.nodeName !== '#text')

        this.reflectComponentAttributes(
            [
                'no-background',
                'ratio',
                'type',
            ],
            slotElements,
        )
    }

}

/*
 * HTML template & CSS style for c-section.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CSectionComponent.template = `<section>
    <c-heading level="4" class="section-title">
        <slot name="title"></slot>
    </c-heading>
    <div class="section-items" type="{$attributes.type}" gap="\${attributes.gap}">
        <slot></slot>
    </div>
</section>`

CSectionComponent.style = `:host {
    --gap: var(--grid-gutter-narrow);
    --max-base: 7.5rem;
    --min-unit: calc(var(--factor) * (var(--max-base) + var(--gap)) - var(--gap));

    display: block;
}

/* ============================================================ *
   ELEMENTS
 * ============================================================ */
section {
    margin-bottom: 3rem;
}

/* ============================================================ *
   VARIATIONS
 * ============================================================ */

/* -------------------- CARDS  -------------------------------- */
:host(:not([type])) {
    --block-item-spacing: var(--grid-gutter-narrow);
}

:host([type="cards"]) .section-items {
    --minmax: minmax(var(--min-unit), 1fr);

    display: grid;
    grid-gap: 0 var(--gap);
    grid-template-columns: repeat(auto-fill, var(--minmax));
    grid-auto-rows: auto;
}

/* -------------------- SIZE  -------------------------------- */
:host([size="xs"]) {
    --factor: 1;
}

:host(:not([size])),
:host([size="sm"]) {
    --factor: 2;
}

:host([size="md"]) {
    --factor: 2.5;
}

:host([size="lg"]) {
    --factor: 4;
}

:host([size="xl"]) {
    --factor: 6;
}

@media (width <= 786px) {
    :host([size="lg"]),
    :host([size="xl"]) {
        --max-base: 1fr;
    }
}

/* -------------------- GAP  -------------------------------- */
:host([gap="wide"]) {
    --gap: var(--grid-gutter);
}

:host([gap="narrow"]) {
    --gap: var(--grid-gutter-narrow);
}

:host([gap="condensed"]) {
    --gap: var(--grid-gutter-condensed);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-section.
 */

window.customElements.define('c-section', CSectionComponent)

/*
 * Default export the concrete class for c-section.
 */

export default CSectionComponent
