/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Concrete web component class for c-site-header.
 * This is automatically generated by the builder.
 */

class CSiteHeaderComponent extends BaseComponent {}

/*
 * HTML template & CSS style for c-site-header.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CSiteHeaderComponent.template = `<header>
    <div class="logo-wrapper">
        <slot name="logo"></slot>
    </div>
    <slot class="left"></slot>
    <slot name="search"></slot>
    <slot name="right">
        <theme-switcher type="swatches"></theme-switcher>
        <theme-mode-switcher></theme-mode-switcher>
    </slot>
</header>`

CSiteHeaderComponent.style = `:host {
    --items-flow: wrap;
    --items-width: auto;

    display: block;
    margin-bottom: 0;
    padding: 0.75rem var(--site-spacing-horizontal);
    z-index: var(--z-index-navigation);
    background: var(--color-ui-1);
    border-bottom: 1px solid var(--color-ui-bg);
}

:host([left]) {
    --items-flow: column;
    --items-width: 100%;

    padding: 0.75rem;
    min-width: 15em;
    max-width: 25em;
}

@media (width >= 768px) {
    :host([sticky]) {
        top: 0;
        position: sticky;
        opacity: 0.97;
    }

    :host([left]) {
        min-height: 100vh;
    }
}

/* -------------------- ELEMENTS -------------------- */
header {
    display: flex;
    flex-flow: var(--items-flow);
    gap: 0 0.5rem;
    flex-wrap: wrap;
    align-items: center;
    height: 100%;
    justify-content: end;
}

header > * {
    width: var(--items-width);
}

header ::slotted(*) {
    gap: 0 0.5rem;
    align-items: center;
    width: 100%;
}

@media (width >= 786px) {
    header {
        gap: 0.5rem 2rem;
    }
}

:host([constrained]) header {
    width: 100%;
    max-width: var(--site-max-width);
}

.logo-wrapper {
    display: block;
    margin-right: auto;
    flex-grow: var(--head-logo-grow, 0);
    max-width: var(--head-logo-max-width, 0);
}

[name="logo"] {
    margin: 0.5rem;
    max-width: 25vw;
}

[name="logo"]::slotted(*) {
    display: flex;
}

.left {
    display: inline-flex;
    flex-flow: row wrap;
    grid-gap: 1rem;
    flex-grow: 1;
}

[name="search"] {
    flex-grow: 2;
    display: block;
    max-width: 25rem;
    margin-left: auto;
}

[name="right"]::slotted(*) {
    display: flex;
    grid-gap: var(--grid-column-spacing);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-site-header.
 */

window.customElements.define('c-site-header', CSiteHeaderComponent)

/*
 * Default export the concrete class for c-site-header.
 */

export default CSiteHeaderComponent
