/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class CTagComponent extends BaseComponent {

    /**
     * The custom context, which is used in the `template.html` file of the
     * c-tag component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        const theme = this.componentAttributes.theme || ''
        const themeColor = theme === 'default' || !theme ? '' : `var(--cd-${theme}-50)`

        return {
            themeColor,
        }
    }

    render() {
        super.render()

        this.setCSSVar()
    }

    /**
     * Sets the icon as inline svg.
     */

    setCSSVar() {
        if (this.customContext.themeColor)
            this.setAttribute('style', `background: ${this.customContext.themeColor}`)
    }

}

/*
 * HTML template & CSS style for c-tag.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
CTagComponent.template = `<span>
    <slot>This is a tag</slot>
</span>`

CTagComponent.style = `:host {
    --color-content-1: var(--color-c-tag);

    display: inline-block;
    color: var(--color-c-tag);
    background: var(--color-c-tag-background);
    font-size: 0.75rem;
    line-height: 1rem;
    padding: 0.25rem 0.5rem;
    transition: var(--transition-property) var(--transition-duration) var(--transition-timing-function);
}

:host([full-width]) {
    width: 100%;
    text-align: center;
}

:host([state]) {
    text-transform: uppercase;
    letter-spacing: var(--letter-spacing-uppercase);
}

:host([state="complete"]) {
    --color-c-tag-background: var(--color-status-success);
}

:host([state="running"]) {
    --color-c-tag-background: var(--color-status-info);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for c-tag.
 */

window.customElements.define('c-tag', CTagComponent)

/*
 * Default export the concrete class for c-tag.
 */

export default CTagComponent
