/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

class FooBarComponent extends BaseComponent {

    /**
     * The custom context, which is used in the `template.html` file of the
     * foo-bar component.
     *
     * @return  {Object}    The custom context
     */

    get customContext() {
        return {
            'title': 'Foo Bar Component',
        }
    }

}

/*
 * HTML template & CSS style for foo-bar.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
FooBarComponent.template = `<div>

    <!--
    __        __   _
    \\ \\      / /__| | ___ ___  _ __ ___   ___
     \\ \\ /\\ / / _ \\ |/ __/ _ \\| '_ \` _ \\ / _ \\
      \\ V  V /  __/ | (_| (_) | | | | | |  __/
       \\_/\\_/ \\___|_|\\___\\___/|_| |_| |_|\\___|

    This component is a showcase component, which includes most of the features
    of Translucent.
    -->

    <!--
    Custom Context
    ==============

    Here's a header component, which uses the context variable \`\${title}\`.
    This variable will be defined in the \`customContext()\` getter.
    -->

    <header>\${title}</header>

    <!--
    Attributes
    ==========

    Component elements support attributes. To access these attributes, you can
    use the \`\${attributes}\` context variable.

    You can also render a list of class names, based on the component's
    attributes. The returned class list will include only the attribute / class
    names which are defined as attribute on the component.
    -->

    <a href="\${attributes.href}">Translucent</a>

    <!--
    Conditionals
    ============

    Some elements should only be rendered when a certain condition is matched.
    This can be achieved by using the \`t-if\` attribute on an element.

    The value of the \`t-if\` attribute is interpreted as normal JavaScript code.
    Thus, you can use any JavaScript syntax and all of the context variables.

    In addition to the custom context (see "Custom Context" section above),
    the following default context variables are available:

        attributes: The component attributes (see "Attributes" section above)
        component:  The component name
        data:       The component data
        item:       The item data (see "Loop" section below)
    -->

    <ul t-if="data">

        <!--
        Loops
        =====

        Some elements should be rendered multiple times. The loop is usually
        based on the received data or on a custom context variable.

        The value of the \`t-for\` attribute is interpreted as normal JavaScript
        code. Simply provide an iterable Object, such as an Array. For each item
        in the given \`t-for\` Object, the node is replicated once. To access the
        current loop item, the context variable \`\${item}\` can be used.

        In case you've several nested loops or you simply want a different
        context variable name than \`\${item}\`, you can also use the
        \`t-for-{varname}\` syntax.

        In addition to the custom context (see "Custom Context" section above),
        the following default context variables are available:

            attributes: The component attributes (see "Attributes" section above)
            component:  The component name
            data:       The component data
        -->

        <li> The data from the fooArray:
            <ul>
                <li t-for="data.fooArray" class="\${item}">\${item}</li>
            </ul>
        </li>
        <li> The data from the fooObject:
            <ul>
                <li t-for-foo="data.fooObject" class="\${foo.key}">\${foo.value}</li>
            </ul>
        </li>

    </ul>

    <!--
    Event Listeners
    ===============

    Sometimes you might to give yourself or a user the possibily to react to
    some events of your component. To do that, you've register a custom event
    listener.

    To register a new event listener, you can use the \`t-on\` attribute. Simply
    use the following syntax:

        {original event}[:{custom event}]

    Please note the \`{custom event}\` is optional.

    Due to the shadow DOM, you or a user can only react to events of a
    component, in case a \`t-on\` attribute and therefore an event listener is
    defined.
    -->

    <c-button t-on="click:fooBarSay" t-for='["foo", "bar"]'>say \${item}</c-button>

</div>`

FooBarComponent.style = `/* stylelint-disable color-named */
:host {
    color           : green;
    font-family     : monospace;
}

header {
    text-transform: uppercase;
    font-weight: bold;
    font-size: 2rem;
}

a {
    border-bottom-style: dotted;
    border-bottom-width: 1px;
    color: magenta;
    text-decoration: none;
}

a:hover {
    color: deeppink;
}

button,
c-button { /* stylelint-disable-line selector-type-no-unknown */
    margin: 0.25rem;
}

/* stylelint-enable color-named */`
/* eslint-enable max-len */

/*
 * Define web component tag for foo-bar.
 */

window.customElements.define('foo-bar', FooBarComponent)

/*
 * Default export the concrete class for foo-bar.
 */

export default FooBarComponent
