/* eslint max-classes-per-file: off, class-methods-use-this: off, max-lines: off */

import BaseComponent from '../base_component.js?v=1.12.1'

/*
 * Custom web component script.
 * This is generated by the builder and loaded from the component's `script.js`.
 */

import {getPath} from '../utils.js?v=1.12.1'


class ThemeSwitcherComponent extends BaseComponent {

    /**
     * The default data.
     *
     * @return  {Array}     The default templates
     */

    get defaultData() {
        const themesPath = getPath('assets/themes/')

        return [
            'default',
            'red',
            'orange',
            'yellow',
            'olive',
            'lime',
            'green',
            'sea-green',
            'azure',
            'blue',
            'violet',
            'purple',
            'fuchsia',
            'rose',
            'hawkeye',
        ].filter(name => document.querySelector(`link[href^="${themesPath}${name}.css"]`))
    }

}

/*
 * HTML template & CSS style for theme-switcher.
 * This is automatically generated by the builder.
 */

/* eslint-disable max-len */
ThemeSwitcherComponent.template = `<div class="theme-switcher-\${attributes.type}">
    <div class="option-label">
        themes
    </div>
    <div class="option-list">
        <button t-on="click:switchTheme" t-for="data" class="option option-\${item}">
            <span class="button-text button-text-\${item}">\${item}</span>
        </button>
        <button t-on="click:resetTheme" class="option option-reset">
            <span class="button-text button-text-reset">reset preferences</span>
        </button>
    </div>
</div>`

ThemeSwitcherComponent.style = `:host {
    display: inline-block;

    --option-list-background: var(--color-ui-5);
    --option-list-color: var(--color-ui-bg);
    --option-list-color-hover: var(--color-ui-1);
    --option-swatch-button-size: 1.5rem;
    --option-swatch-size: calc(var(--option-swatch-button-size));
}

.option-list {
    margin: 0;
    padding: 0;
    list-style: none;
}

.option:hover,
:host([type="flyout"]) .theme-switcher:hover {
    cursor: pointer;
}

.option:focus {
    outline: 0;
}

/* ============================================================ *
   SWATCHES
   Show the theme switcher as color swatches
 * ============================================================ */

:host([type="swatches"]) .option-label {
    display: none;
}

:host([type="swatches"]) .option-list {
    display: flex;
    flex-wrap: wrap;
}

:host([type="swatches"]) .option {
    position: relative;
    border: 0;
    display: flex;
    align-items: center;
    padding: 0.25rem;
    width: var(--option-swatch-button-size);
    height: var(--option-swatch-button-size);
    border-radius: 300px;
    margin: 0.25rem 0.25rem 0.25rem 0;
    background-color: var(--cd-grey-60);
}

:host([type="swatches"]) .option-red {
    background-color: var(--cd-red-60);
}

:host([type="swatches"]) .option-orange {
    background-color: var(--cd-orange-60);
}

:host([type="swatches"]) .option-yellow {
    background-color: var(--cd-yellow-60);
}

:host([type="swatches"]) .option-olive {
    background-color: var(--cd-olive-60);
}

:host([type="swatches"]) .option-lime {
    background-color: var(--cd-lime-60);
}

:host([type="swatches"]) .option-green {
    background-color: var(--cd-green-60);
}

:host([type="swatches"]) .option-sea-green {
    background-color: var(--cd-sea-green-60);
}

:host([type="swatches"]) .option-blue {
    background-color: var(--cd-blue-60);
}

:host([type="swatches"]) .option-azure {
    background-color: var(--cd-azure-60);
}

:host([type="swatches"]) .option-violet {
    background-color: var(--cd-violet-60);
}

:host([type="swatches"]) .option-purple {
    background-color: var(--cd-purple-60);
}

:host([type="swatches"]) .option-fuchsia {
    background-color: var(--cd-fuchsia-60);
}

:host([type="swatches"]) .option-rose {
    background-color: var(--cd-rose-60);
}

:host([type="swatches"]) .option-hawkeye {
    background: linear-gradient(-45deg, var(--cd-purple-20) 50%, var(--cd-purple-60) 50%) repeat;
}

:host([type="swatches"]) .option-reset {
    background-color: var(--cd-grey-30);
    color: var(--cd-cold-grey-80);
}

:host([type="swatches"]) .option-reset::before,
:host([type="swatches"]) .option-reset::after {
    position: absolute;
    left: 50%;
    margin-left: -1px;
    content: ' ';
    height: 0.75rem;
    width: 2px;
    background-color: var(--cd-cold-grey-90);
}

:host([type="swatches"]) .option-reset::before {
    transform: rotate(45deg);
}

:host([type="swatches"]) .option-reset::after {
    transform: rotate(-45deg);
}

:host([type="swatches"]) .button-text {
    position: absolute;
    bottom: calc(0.25rem + var(--option-swatch-button-size));
    left: -2.5rem;
    margin-left: 50%;
    width: 5rem;
    z-index: var(--z-index-front);
    color: var(--cd-grey-100);
    line-height: 1;
    text-align: center;
    background: inherit;
    border-radius: var(--border-radius);
    padding: 0.25rem;
    display: none;
}

:host([type="swatches"]) .option:hover .button-text {
    display: block;
}

/* ============================================================ *
   FLYOUT
   Show the theme switcher as navigation list with flyout
 * ============================================================ */
:host([type="flyout"]) .option-label {
    z-index: var(--z-index-front);
    position: relative;
    width: auto;
    display: inline-block;
    padding: 0.25rem;
    text-transform: uppercase;
    border: var(--border-default);
    border-bottom: 0;
    border-color: transparent;
}

:host([state="hover"]) .option-label,
:host([type="flyout"]) .theme-switcher:hover .option-label {
    border-color: var(--border-default-color);
    background: var(--option-list-background);
    color: var(--option-list-color);
}

:host([type="flyout"]) .option-list {
    position: absolute;
    border: var(--border-default);
    margin-top: -1px;
    display: none;
}

:host([state="hover"]) .option-list,
:host([type="flyout"]) .theme-switcher:hover .option-list {
    display: block;
}

:host([type="flyout"]) .option {
    padding: 0.25rem;
    font-family: var(--font-family);
    font-size: 0.875rem;
    text-align: left;
    text-decoration: none;
    line-height: 1.5rem;
    border: 0;
    transition: all 0.1s ease-out;
    display: block;
    width: 100%;
    background: var(--option-list-background);
    color: var(--option-list-color);
}

:host([type="flyout"]) .option-reset {
    border-top: 1px dashed var(--option-list-color);
}

:host([type="flyout"]) .option:hover {
    color: var(--option-list-color-hover);
}`
/* eslint-enable max-len */

/*
 * Define web component tag for theme-switcher.
 */

window.customElements.define('theme-switcher', ThemeSwitcherComponent)

/*
 * Default export the concrete class for theme-switcher.
 */

export default ThemeSwitcherComponent
