/*
 * The cookie handling class.
 */

class Cookie {

    /**
     * Get all cookies.
     *
     * @return  {object} The cookies
     */

    static get cookies() {
        if (!document.cookie)
            return {}

        const decode = decodeURIComponent
        return document.cookie
            .split(';')
            .map(cookie => cookie.split('='))
            .reduce((obj, pairs) => {
                obj[decode(pairs[0].trim())] = decode(pairs[1].trim())
                return obj
            }, {})
    }

    /**
     * Get a cookies.
     *
     * @param   {String} name   The name of the cookie
     *
     * @return  {String}        The value
     */

    static get(name) {
        return Cookie.cookies[name]
    }

    /**
     * Set a cookie.
     *
     * If the ``expireDays`` parameter is not set, the cookie is valid until
     * the browser is closed (session cookie).
     *
     * @param   {String} name           The name of the cookie
     * @param   {String} value          The value of the cookie
     * @param   {Integer} expireDays    The expire in days (optional)
     */

    static set(name, value, expireDays) {
        let expires = ''

        if (expireDays) {
            const time            = new Date()
            const dayMicroseconds = 86400000
            time.setTime(time.getTime() + (dayMicroseconds * expireDays))
            expires = `expires=${time.toUTCString()}`
        }

        document.cookie = `${name.trim()}=${value.trim()};${expires};path=/`
    }


    /**
     * Delete a cookie.
     *
     * @param   {String} name   The name of the cookie
     */

    static delete(name) {
        document.cookie = `${name.trim()}=; Max-Age=0`
    }

}

export default Cookie
