/**
 * A custom event class for the components.
 */

class ComponentEvent extends Event {

    /**
     * The constructor.
     *
     * @param   {String}    type    The event type
     */

    constructor(type) {
        super(type, {
            'bubbles': true,        // Bubble event through all shadow DOM elements.
            'cancelable': true,     // Make event cancelable.
            'composed': true,       // Let event pass shadow DOM boundary.
        })
    }

    /**
     * All informations from the web component itself, packed in a clean
     * object with the following properties:
     *
     * - ``component``: The component itself
     * - ``target``: The target within the component on which the event was dispatched
     * - ``type``: The Translucent event type
     *
     * @return  {Object}    The info object
     */

    get info() {
        return {
            'component': this.target,
            'target': this.composedPath()[0],
            'type': this.type,
        }
    }

}

export default ComponentEvent
