 
export default {
    argTypes: {
        data: {
            control: 'object',
            description: 'A json object to render the breadcrumb.',
        },
        slotDefault: {
            control: 'text',
            description: 'Slotted content - expects a list of `li` ' +
                'elements to render the breadcrumb',
            table: {
                type: {summary: 'string'},
            },
        },
    },
    parameters: {
        docs: {
            description: {
                component: 'Renders a breadcrumb either out of a json ' +
                    'object or some slotted list items.',
            },
        },
    },
    tags: ['autodocs'],
    title: 'Simple/Breadcrumb',
}

const Template = ({ data, slotDefault }) => {
    const template = document.createElement('c-breadcrumb')

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}


export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: {
        breadcrumb: [
            {
                name: 'Level 1',
                url: '#',
            },
            {
                name: 'Level 2',
                url: '#',
            },
            {
                name: 'Active Site',
            },
        ],
    },
}

export const DataViaSlot = Template.bind({})
DataViaSlot.args = {
    slotDefault: '<li><c-link href="#">Level 1</c-link></li>\n' +
        '<li><c-link href="#">Level 2</c-link></li>\n' +
        '<li>Active Site</li>',
}
 
