
const iconsObject = [
    'applications',
    'arrow-down',
    'arrow-left',
    'arrow-right',
    'arrow-up',
    'back',
    'calendar',
    'check',
    'chevron-down',
    'chevron-left',
    'chevron-right',
    'chevron-up',
    'clock',
    'cross',
    'dash',
    'environment',
    'exclamation-mark',
    'external',
    'flash',
    'flow-1',
    'flow-2',
    'flow-3',
    'folder',
    'forward',
    'gear',
    'hashtag',
    'info',
    'list',
    'location',
    'log-in',
    'log-out',
    'magic-wand',
    'media',
    'moon',
    'node',
    'nodes',
    'patch-run',
    'pause',
    'person',
    'play',
    'plus',
    'restart',
    'restart-2',
    'restart-3',
    'rocket',
    'save',
    'search',
    'sun',
    'thumb-up',
    'thumbnails',
    'trash',
    'user-ok',
    'versions',
    'warning',
]

export default {
    argTypes: {
        action: {
            control: {type: 'inline-radio'},
            description: 'The `action` attribute sets a dedicated hover color to give a  ' +
                'hint what will happen, when the button is clicked.',
            mapping: {
                default: '',
            },
            options: ['confirmation', 'attention', 'default'],
            table: {
                type: {summary: 'string'},
            },
        },
        flags: {
            control: 'inline-check',
            options: ['disabled', 'full-width', 'padded'],
        },
        icon: {
            control: {type: 'select'},
            description: 'Optional icon for the button.',
            options: iconsObject,
            table: {
                category: 'icon',
                type: {summary: 'string'},
            },
        },
        iconPositionRight: {
            control: {type: 'boolean'},
            description: 'Optionally, the icon can be displayed on the right side of a text ' +
                'button.',
            table: {
                category: 'icon',
                defaultValue: {summary: 'boolean'},
                type: {summary: 'boolean'},
            },
        },
        label: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        size: {
            control: {type: 'inline-radio'},
            description: 'The size attribute affects the icon and is intended for icon-only ' +
                'buttons.',
            mapping: {
                default: '',
                'extra-large': 'xl',
                large: 'lg',
                medium: 'md',
            },
            options: ['medium', 'large', 'extra-large', 'default'],
            table: {
                category: 'icon',
                defaultValue: {summary: 'medium'},
                type: {summary: 'string'},
            },
        },
        type: {
            control: {type: 'inline-radio'},
            description: 'Use the primary button for important actions. For the most cases ' +
                'the secondary button will be the best choice.',
            options: ['primary', 'secondary', 'tertiary'],
            table: {
                defaultValue: {summary: 'primary'},
                type: {summary: 'string'},
            },
        },
    },
    args: {
        iconPositionRight: 0,
    },
    parameters: {
        docs: {
            description: {
                component: 'Use a button to perform an action that affects the websites ' +
                    'front- or backend. <br/> (Use a <code>c-link</code> to navigate to ' +
                    'another page.)',
            },
        },
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Simple/Button',
}

// eslint-disable-next-line max-statements
const Template = ({ ...args }) => {
    const template = document.createElement('c-button')

    if (args.type) 
        template.setAttribute(args.type, '')
    if (args.flags) {
        for (const flag of args.flags)
            template.setAttribute(flag, '')
    }
    if (args.action) 
        template.setAttribute('action', args.action)
    if (args.icon) 
        template.setAttribute('icon', args.icon)
    if (args.iconPositionRight) 
        template.setAttribute('icon-position', 'right')
    if (args.size) 
        template.setAttribute('size', args.size)

    if (args.label) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(args.label)
        template.append(...fragment.childNodes)
    }

    return template
}

export const Default = Template.bind({})
Default.args = {
    icon: 'log-in',
    label: 'Primary Button',
}

export const Secondary = Template.bind({})
Secondary.args = {
    label: 'Secondary Button',
    type: 'secondary',
}

export const Tertiary = Template.bind({})
Tertiary.args = {
    label: 'Tertiary Button',
    type: 'tertiary',
}

export const IconOnly = Template.bind({})
IconOnly.args = {
    icon: 'check',
    size: 'lg',
}

export const Confirmation = Template.bind({})
Confirmation.args = {
    action: 'confirmation',
}
