 
export default {
    argTypes: {
        data: {
            control: 'object',
            table: {
                category: 'data',
            },
        },
        error: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        flags: {
            control: 'inline-check',
            options: ['disabled', 'required', 'button'],
            table: {
                category: 'attributes',
            },
        },
        help: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        label: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        labelPosition: {
            control: 'inline-radio',
            mapping: {
                default: '',
            },
            options: ['default', 'left'],
            table: {
                category: 'attributes',
            },
        },
        slotDefault: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        slotHelp: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        value: {
            control: 'text',
            table: {
                category: 'data',
            },
        },
    },
    args: {
        labelPosition: 'default',
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Composed Components/Forms/Checkbox',
}

// eslint-disable-next-line max-statements
const Template = ({data, error, help, label, slotDefault, flags, labelPosition, slotHelp}) => {
    const template = document.createElement('c-checkbox')

    if (flags) {
        flags.toString().split(',').forEach(flag => {
            if (flag.trim()) 
                template.setAttribute(flag.trim(), '')
        })
    }

    if (labelPosition) 
        template.setAttribute('label-position', labelPosition)
    

    const attributes = { error, help, label }
    for (const [key, value] of Object.entries(attributes)) {
        if (value && value !== '')
            template.setAttribute(key, value)
    }

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))
    

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    if (slotHelp) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotHelp)
        const helpSlot = document.createElement('div')
        helpSlot.setAttribute('slot', 'help')
        helpSlot.append(...fragment.childNodes)
        template.appendChild(helpSlot)
    }

    return template
}


export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: [
        {
            checked: true,
            label: 'Apple',
            value: 'apple',
        },
        {
            checked: true,
            label: 'Kiwi',
            value: 'kiwi',
        },
        {
            label: 'Banana',
            value: 'banana',
        },
        {
            disabled: true,
            label: 'I am disabled',
            value: 'disabled',
        },
        {
            checked: true,
            disabled: true,
            label: 'I am disabled and initially checked',
            value: 'disabled_checked',
        },
    ],
    flags: 'required',
    help: 'Some help text.',
    label: 'I am a  label',
    value: 'apple',
}

export const DataViaSlot = Template.bind({})
DataViaSlot.args = {
    slotDefault: 'I\'m a single Checkbox with slotted content',
}

export const WithError = Template.bind({})
WithError.args = {
    ...DataViaObject.args,
    error: 'Please review your input.',
    labelPosition: 'left',
}

export const ButtonStyle = Template.bind({})
ButtonStyle.args = {
    ...DataViaObject.args,
    flags: 'button',
}
 
