const allHeadings = '<c-heading level="1">I am a h1 heading.</c-heading>' +
    '<c-heading level="2">I am a h2 heading.</c-heading>' +
    '<c-heading level="3">I am a h3 heading.</c-heading>' +
    '<c-heading level="4">I am a h4 heading.</c-heading>'

 

export default {
    argTypes: {
        level: {
            control: 'inline-radio',
            defaultValue: 'h1',
            description: 'The semantic level for the corresponding Markup element.',
            mapping: {
                h1: '1',
                h2: '2',
                h3: '3',
                h4: '4',
            },
            options: ['h1', 'h2', 'h3', 'h4'],
            table: {
                defaultValue: {summary: 'h1'},
                type: {summary: 'string'},
            },
        },
        slotDefault: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
    },
    args: {
        level: 'h1',
    },
    parameters: {
        docs: {
            description: {
                component: `All Headings: ${allHeadings}`,
            },
        },
    },
    tags: ['autodocs'],
    title: 'Simple/Heading',
}

const Template = ({level, slotDefault}) => {
    const template = document.createElement('c-heading')

    if (level)
        template.setAttribute('level', level)

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const Heading = Template.bind({})
Heading.args = {
    slotDefault: 'Some heading content.',
}
 

