 
export default {
    argTypes: {
        alt: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        inline: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Set the attribute `ìnline` to use the image in combination with text.',
            table: {
                category: 'Inline Image',
                table: {
                    type: {summary: 'boolean'},
                },
            },
        },
        src: {
            control: 'text',
            description: 'The default source used for the image.',
            table: {
                category: 'source',
                type: {summary: 'string'},
            },
        },
        srcDark: {
            control: 'text',
            description: 'The source used, when the `mode-dark`is active.',
            table: {
                category: 'source',
                type: {summary: 'string'},
            },
        },
        srcLight: {
            control: 'text',
            description: 'The source used, when the `mode-light`is active.',
            table: {
                category: 'source',
                type: {summary: 'string'},
            },
        },
        width: {
            control: 'number',
            table: {
                type: {summary: 'int'},
            },
        },
        withDemoText: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Flag, for activating some demo text for demonstrating ' +
                'the inline-value of an image.',
            table: {
                category: 'Inline Image',
            },
        },
    },
    args: {
        inline: 0,
        withDemoText: 0,

    },
     
    parameters: {
        docs: {
            description: {
                component: 'When either the attribute `src-light` or `src-dark` is' +
                    ' set,then the image will react on the set theme-mode.',
            },
        },
    },
    tags: ['autodocs'],
    title: 'Simple/Image',
}

const Template = ({alt, inline, src, srcdark, srclight, width, withDemoText}) => {
    const template = document.createElement('div')
    const image = document.createElement('c-image')

    const attributes = {alt, inline, src, srcdark, srclight, width}
    for (const [key, value] of Object.entries(attributes)) {
        if (value !== null && value !== '' && value !== false && value)
            image.setAttribute(key, value)
    }

    if (withDemoText) {
        const textNode = document.createTextNode('Some demo Text ')
        template.appendChild(textNode)
    }

    template.appendChild(image)
    return template
}

export const Default = Template.bind({})
Default.args = {
    src: 'https://placehold.co/300x200',
}

export const Modes = Template.bind({})
Modes.args = {
    srcdark: 'translucent/assets/img/logo-dark.svg',
    srclight: 'translucent/assets/img/logo-light.svg',
    width: 240,
}
 
