 

export default {
    argTypes: {
        external: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Add a visual indicator, that the link leads to an external site.',
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        fullWidth: {
            control: 'boolean',
            defaultValue: 0,
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        href: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        slotDefault: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        target: {
            control: 'inline-radio',
            options: ['_blank', '_self'],
            table: {
                type: {summary: 'string'},
            },
        },
        title: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        type: {
            control: 'inline-radio',
            options: ['primary', 'secondary', 'tertiary'],
            table: {
                defaultValue: {summary: 'primary'},
                type: {summary: 'string'},
            },
        },
    },
    args: {
        external: 0,
        fullWidth: 0,
    },
    parameters: {
        docs: {
            description: {
                component: 'Use a link to navigate to another page. <br/> (Use a ' +
                    '<code>c-button</code> to perform an action.)',
            },
        },
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Simple/Link',
}

const Template = ({external, fullWidth, href, slotDefault, target, title, type}) => {
    const template = document.createElement('c-link')

    const attributes = {external, href, target, title, type}
    for (const [key, value] of Object.entries(attributes)) {
        if (value !== null && value !== '' && value !== false && value)
            template.setAttribute(key, value)
    }

    if (fullWidth)
        template.setAttribute('full-width', '')


    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const Default = Template.bind({})
Default.args = {
    slotDefault: 'Hi, i am a link.',
}

export const External = Template.bind({})
External.args = {
    external: true,
    slotDefault: 'I link to external content',
}

export const FullWidth = Template.bind({})
FullWidth.args = {
    fullWidth: true,
    slotDefault: 'I am a full-width link.',
}

export const Secondary = Template.bind({})
Secondary.args = {
    slotDefault: 'I am a secondary link.',
    type: 'secondary',
}

export const Tertiary = Template.bind({})
Tertiary.args = {
    slotDefault: '<c-image src="translucent/assets/img/logo-translucent.svg" width="40" ' +
        'alt="Alt Tag for Image" theme-mode="light"></c-image>',
    type: 'tertiary',
}
 