 

export default {
    argTypes: {
        data: {
            control: 'object',
            description: 'json object to pass to the component for the list rendering.',
        },
        ordered: {
            control: 'boolean',
            description: 'Flag to define the list as a ordered `ol` list (instead of unordered' +
                ' `ul`).',
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        slotDefault: {
            control: 'text',
            description: 'Alternative to pass list elements (`li`) as HTML markup.',
            table: {
                type: {summary: 'string'},
            },
        },
    },
    args: {
        ordered: false,
    },
    parameters: {
        docs: {
            description: {
                component: 'A list (`ul li` or `ol li`) can be created via a json object or by ' +
                    'providing HTML markup in the default slot `slotDefault`.',
            },
        },
    },
    tags: ['autodocs'],
    title: 'Simple/List',
}

const Template = ({data, ordered, slotDefault}) => {
    const template = document.createElement('c-list')

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))

    if (ordered) 
        template.setAttribute('ordered', '')
    

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }
    
    return template
}

export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: [
        'This is the first item of an unordered list',
        'The second item',
        'And another item',
    ],
}

export const DataViaSlot = Template.bind({})
DataViaSlot.args = {
    slotDefault: '<li>First item</li><li>Second item</li>',
}

export const OrderedList = Template.bind({})
OrderedList.args = {
    ...DataViaObject.args,
    ordered: true,
}
