 

export default {
    argTypes: {
        data: {
            control: 'object',
            description: 'A json object to render the navigation.',
        },
        horizontal: {
            control: 'boolean',
            defaultValue: 0,
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        slotDefault: {
            control: 'text',
            description: 'Alternative to pass elements as HTML markup.',
            table: {
                type: {summary: 'string'},
            },
        },
        uppercase: {
            control: 'boolean',
            defaultValue: 0,
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
    },
    args: {
        horizontal: 0,
        uppercase: 0,
    },
    tags: ['autodocs'],
    title: 'Simple/Navigation',
}

const Template = ({data, horizontal, slotDefault, uppercase}) => {
    const template = document.createElement('c-navigation')

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))

    if (horizontal) 
        template.setAttribute('horizontal', '')

    if (uppercase) 
        template.setAttribute('uppercase', '')

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: {
        items: [
            {
                class: 'test-class',
                href: '#',
                name: 'first link',
                status: 'is-active',
                target: '_blank',
            },
            {
                class: 'test-class',
                href: '#',
                name: 'Second link',
                target: '_blank',
            },
        ],
    },
}

export const DataViaSlot = Template.bind({})
DataViaSlot.args = {
    slotDefault: '<c-link href="#">First Link</c-link><c-link href="#">Second Link</c-link>',
}

export const Horizontal = Template.bind({})
Horizontal.args = {
    ...DataViaObject.args,
    horizontal: true,
}

export const MultiLevel = Template.bind({})
MultiLevel.args = {
    data: {
        items: [
            {
                href: '#',
                items: [
                    {
                        href: '#',
                        name: 'Level 2 (#1.1)',
                        status: 'is-active',
                        target: '_blank',
                        title: 'Link 2.1',
                    },
                    {
                        href: '#',
                        name: 'Level 2 (#1.2)',
                        target: '_blank',
                        title: 'Link 2.2',
                    },
                ],
                name: 'Level 1 (#1)',
                status: 'is-active',
                target: '_blank',
                title: 'Link 1.1',
            },
            {
                href: '#',
                items: [
                    {
                        href: '#',
                        name: 'Level 2 (#2.1)',
                        status: 'is-active',
                        target: '_blank',
                        title: 'Link 2.1',
                    },
                    {
                        href: '#',
                        name: 'Level 2 (#2.2)',
                        target: '_blank',
                        title: 'Link 2.2',
                    },
                    {
                        href: '#',
                        name: 'Level 2 (#2.3) with a longer content',
                        target: '_blank',
                        title: 'Link 2.3',
                    },
                ],
                name: 'Level 1 (#2)',
            },
            {
                href: '#',
                name: 'Level 1 (#3)',
                status: 'is-active',
                target: '_blank',
            },
        ],
    },
}

export const MultiLevelHorizontal = Template.bind({})
MultiLevelHorizontal.args = {
    ...MultiLevel.args,
    horizontal: true,
}
