 

export default {
    argTypes: {
        slotDefault: {control: 'text'},
        slotTitle: {control: 'text'},
        type: {
            control: 'inline-radio',
            defaultValue: 'info',
            options: ['info', 'success', 'warning', 'error'],
            table: {
                defaultValue: {summary: 'info'},
                type: {summary: 'string'},
            },
        },
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Simple/Notification',
}


// eslint-disable-next-line max-statements
const Template = ({slotDefault, slotTitle, type}) => {
    const template = document.createElement('c-notification')

    if (type) 
        template.setAttribute('type', type)

    if (slotTitle) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotTitle)
        const titleSlot = document.createElement('div')
        titleSlot.setAttribute('slot', 'help')
        titleSlot.append(...fragment.childNodes)
        template.appendChild(titleSlot)
    }

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const Info = Template.bind({})
Info.args = {
    slotDefault: 'I am an informative notification',
    slotTitle: 'I am the notifications optional title.',
}

export const Success = Template.bind({})
Success.args = {
    slotDefault: 'Success! Everything is awesome!',
    type: 'success',
}

export const Warning = Template.bind({})
Warning.args = {
    slotDefault: 'For more information about this warning check the <c-link>FAQ\'s</c-link>',
    type: 'warning',
}

export const Error = Template.bind({})
Error.args = {
    slotDefault: 'Uh, oh, there is an error. Right over there. Go and fix it.',
    type: 'error',
}
