 

export default {
    argTypes: {
        fullWidth: {
            control: 'boolean',
            description: 'Remove the maximum line-length and use the full-width of the parent ' +
                'container.',
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        type: {
            control: 'inline-radio',
            description: 'Optionally render an alternative style for the text.',
            options: ['default', 'lead'],
            table: {
                defaultValue: {summary: 'default'},
                type: {summary: 'string'},
            },
        },
    },
    args: {
        fullWidth: false,
    },
    parameters: {
        docs: {
            description: {
                component: 'Use a link to navigate to another page. <br/> (Use a ' +
                    '<code>c-button</code> to perform an action.)',
            },
        },
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Simple/Paragraph',
}

const Template = ({fullWidth, slotDefault, type}) => {
    const template = document.createElement('c-p')

    if (fullWidth) 
        template.setAttribute('full-width', '')

    if (type) 
        template.setAttribute('type', type)

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const Default = Template.bind({})
Default.args = {
    slotDefault: 'But with the blast shield down, I can\'t even see! How am I ' +
        'supposed to fight? Alderaan? I\'m not going to Alderaan. I\'ve got to go ' +
        'home. It\'s late, I\'m in for it as it is. The plans you refer to will soon ' +
        'be back in our hands.',
}

export const Lead = Template.bind({})
Lead.args = {
    ...Default.args,
    type: 'lead',
}

export const FullWidth = Template.bind({})
FullWidth.args = {
    ...Default.args,
    fullWidth: true,
}
