 

export default {
    argTypes: {
        colour: {
            control: 'inline-radio',
            defaultValue: 'info',
            options: ['neutral', 'theme', 'info', 'success', 'warning', 'error'],
            table: {
                defaultValue: {summary: 'info'},
                type: {summary: 'string'},
            },
        },
        fullWidth: {
            control: 'boolean',
            defaultValue: 0,
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        slotDefault: {
            control: 'text',
            table: {
                type: {summary: 'string'},
            },
        },
        value: {
            control: 'number',
            table: {
                type: {summary: 'int'},
            },
        },
    },
    args: {
        colour: 'neutral',
        fullWidth: 0,
        value: 33,
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Simple/Progress',
}

const Template = ({colour, fullWidth, slotDefault, type, value}) => {
    const template = document.createElement('c-progress')

    if (fullWidth) 
        template.setAttribute('full-width', '')

    if (colour) 
        template.setAttribute('colour', colour)

    if (type) 
        template.setAttribute('type', type)

    if (value) 
        template.setAttribute('value', value)

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}


export const Default = Template.bind({})
Default.args = {
    slotDefault: 'Hi, i am the label.',
}

export const FullWidth = Template.bind({})
FullWidth.args = {
    fullWidth: true,
    slotDefault: 'I am a full-width progress.',
}

export const WithoutLabel = Template.bind({})
WithoutLabel.args = {
    colour: 'info',
    fullWidth: true,
    slotDefault: '',
}

