 

export default {
    argTypes: {
        gap: {
            control: {type: 'inline-radio'},
            description: 'Gap between the blocks',
            options: ['wide', 'narrow', 'condensed'],
            table: {
                defaultValue: {summary: 'narrow'},
                type: {summary: 'string'},
            },
        },
        noBackground: {type: 'boolean'},
        ratio: {
            control: {type: 'inline-radio'},
            description: 'The defined ratio for the blocks.',
            options: ['2x1', '4x3', '1x1', '3x4', '1x2'],
        },
        slotDefault: {
            control: 'text',
            description: 'Slot for all block and other elements.',
        },
        slotTitle: {
            control: 'text',
            description: 'Title of the Section.',
        },
        type: {
            control: {type: 'inline-radio'},
            description: 'Defines how the elements in the section will be rendered.',
            options: ['cards', 'list', 'timeline'],
            table: {
                defaultValue: {summary: 'cards'},
                type: {summary: 'string'},
            },
        },
    },
    args: {
        gap: 'narrow',
        noBackground: false,
        ratio: '2x1',
        type: 'cards',
    },
    parameters: {
        docs: {
            description: {
                component: 'The `c-section` usually wraps one or multiple `c-card` components. ' +
                    'It defines also the style of them.',
            },
        },
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Composed Components/Section and Blocks/Section',
}

// eslint-disable-next-line max-statements
const Template = ({gap, noBackground, ratio, slotTitle, slotDefault, type}) => {
    const template = document.createElement('c-section')

    if (ratio) 
        template.setAttribute('ratio', ratio)

    if (type) 
        template.setAttribute('type', type)

    if (gap) 
        template.setAttribute('gap', gap)

    if (noBackground) 
        template.setAttribute('no-background', '')

    if (slotTitle) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotTitle)
        const titleSlot = document.createElement('div')
        titleSlot.setAttribute('slot', 'help')
        titleSlot.append(...fragment.childNodes)
        template.appendChild(titleSlot)
    }
    
    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const Default = Template.bind({})
Default.args = {
    gap: 'narrow',
    ratio: '2x1',
    slotDefault: '<c-block icon="cross" position="middle" ratio="1x1" title="I am a title.">' +
        'I am content in the Default slot.<div slot="bottom">I am content in the Bottom slot.' +
        '</div><div slot="footer">I am content in the Footer slot.</div><div slot="header">' +
        'I am content in the Header slot.</div></c-block><c-block>Content of Block' +
        ' 2</c-block><c-block>Content of Block 3</c-block>',
    slotTitle: 'I am the section title.',
    type: 'cards',
}

export const List = Template.bind({})
List.args = {
    ...Default.args,
    gap: '',
    ratio: '',
    type: 'list',
}

export const Timeline = Template.bind({})
Timeline.args = {
    ...Default.args,
    gap: '',
    ratio: '',
    type: 'timeline',
}
