 

export default {
    argTypes: {
        data: {
            control: 'object',
            table: {
                category: 'data',
            },
        },
        error: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        flags: {
            control: 'inline-check',
            options: ['disabled', 'hassearch', 'required', 'multiple'],
            table: {
                category: 'attributes',
            },
        },
        formSkin: {
            control: 'inline-radio',
            mapping: {
                default: '',
            },
            options: ['underline', 'bordered', 'default'],
            table: {
                category: 'attributes',
            },
        },
        help: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        label: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        labelPosition: {
            control: 'inline-radio',
            mapping: {
                default: '',
            },
            options: ['default', 'left', 'inside'],
            table: {
                category: 'attributes',
            },
        },
        placeholder: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        slotHelp: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        value: {
            control: 'text',
            table: {
                category: 'data',
            },
        },
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Composed Components/Forms/Select',
}

// eslint-disable-next-line max-statements
const Template = ({error, flags, formSkin, help, label, labelPosition, placeholder, slotHelp,
    value, data, slotDefault}) => {
    const template = document.createElement('c-select')

    if (flags) {
        flags.toString().split(',').forEach(flag => {
            const trimmed = flag.trim()
            if (trimmed) 
                template.setAttribute(trimmed, '')
        })
    }

    if (labelPosition) 
        template.setAttribute('label-position', labelPosition)
    if (formSkin) 
        template.setAttribute('form-skin', formSkin)

    const attributes = {error, help, label, placeholder, value}
    for (const [key, val] of Object.entries(attributes)) {
        if (val && val !== '')
            template.setAttribute(key, val)
    }

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    if (slotHelp) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotHelp)
        const helpSlot = document.createElement('div')
        helpSlot.setAttribute('slot', 'help')
        helpSlot.append(...fragment.childNodes)
        template.appendChild(helpSlot)
    }

    return template
}

export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: [
        {
            checked: true,
            label: 'Apple',
            value: 'apple',
        },
        {
            checked: true,
            label: 'Kiwi',
            value: 'kiwi',
        },
        {
            label: 'Banana',
            value: 'banana',
        },
        {
            disabled: true,
            label: 'I am disabled',
            value: 'disabled',
        },
        {
            checked: true,
            disabled: true,
            label: 'I am disabled and initially checked',
            value: 'disabled_checked',
        },
    ],
    flags: 'required',
    help: 'Some help text.',
    label: 'I am the label',
    value: 'apple',
}

export const WithError = Template.bind({})
WithError.args = {
    ...DataViaObject.args,
    error: 'Please review your input.',
    labelPosition: 'left',
}
