 

export default {
    argTypes: {
        constrained: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Constrain the header to the max with defined in the project.',
        },
        left: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Align the header as a sidebar to the left',
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
        slotDefault: {
            control: 'text',
            description: 'Middle slot, usually for the navigation.',
        },
        slotLogo: {
            control: 'text',
            description: 'Left slot for the logo.',
        },
        slotRight: {
            control: 'text',
            description: 'Slot on the right, usually contains the switcher components.',
            table: {
                defaultValue: {summary: 'theme and mode switcher'},
            },
        },
        slotSearch: {
            control: 'text',
            description: 'Slot between default and right, holding the search compnent.',
        },
        sticky: {
            control: 'boolean',
            defaultValue: 0,
            description: 'Make the header stick to the top of the page.',
            table: {
                defaultValue: {summary: false},
                type: {summary: 'boolean'},
            },
        },
    },
    args: {
        constrained: false,
        sticky: false,
    },
    parameters: {
        docs: {
            description: {
                component: `<c-notification>Please note, that the effect 
of <code>constrained</code> and <code>sticky</code> might be invisible in 
storybook.</c-notification>`,
            },
        },
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Layout Components/Site Header',
}


// eslint-disable-next-line max-statements
const Template = ({constrained, left, slotDefault, slotLogo, slotRight, slotSearch, sticky}) => {
    const template = document.createElement('c-site-header')

    if (constrained) 
        template.setAttribute('constrained', '')
    if (sticky) 
        template.setAttribute('sticky', '')
    if (left) 
        template.setAttribute('left', '')

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    if (slotLogo) {
        const logoEl = document.createElement('div')
        logoEl.setAttribute('slot', 'logo')
        const fragment = document.createRange().createContextualFragment(slotLogo)
        logoEl.append(...fragment.childNodes)
        template.appendChild(logoEl)
    }

    if (slotRight) {
        const rightEl = document.createElement('div')
        rightEl.setAttribute('slot', 'right')
        const fragment = document.createRange().createContextualFragment(slotRight)
        rightEl.append(...fragment.childNodes)
        template.appendChild(rightEl)
    }

    if (slotSearch) {
        const searchEl = document.createElement('div')
        searchEl.setAttribute('slot', 'search')
        const fragment = document.createRange().createContextualFragment(slotSearch)
        searchEl.append(...fragment.childNodes)
        template.appendChild(searchEl)
    }

    return template
}

export const Default = Template.bind({})
Default.args = {}

export const Slots = Template.bind({})
Slots.args = {
    slotDefault: '[ Slot: default ]',
    slotLogo: '[ Slot: logo ]',
    slotRight: '[ Slot: right ]',
    slotSearch: '[ Slot: search ]',
}
