 

export default {
    argTypes: {
        caption: {control: 'text'},
        data: {control: 'object'},
        flags: {
            control: 'inline-check',
            options: ['horizontal-rulers', 'full-width', 'hide-last-ruler'],
        },
        slotDefault: {control: 'text'},
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Composed Components/Tables/Table',
}

const Template = ({caption, data, flags, slotDefault}) => {
    const template = document.createElement('c-table')

    if (data) 
        template.setAttribute('data-data', JSON.stringify(data))

    if (caption) 
        template.setAttribute('caption', caption)

    if (flags) {
        for (const flag of flags)
            template.setAttribute(flag, '')
    }

    if (slotDefault) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(slotDefault)
        template.appendChild(fragment)
    }

    return template
}

export const DataViaObject = Template.bind({})
DataViaObject.args = {
    data: [
        {
            albums: 9,
            band: 'Buzzcocks',
            formed: 1976,
            song: 'Ever Fallen In Love',
        },
        {
            albums: 6,
            band: 'The Clash',
            formed: 1976,
            song: 'London Calling',
        },
        {
            albums: 17,
            band: 'The Stranglers',
            formed: 1974,
            song: 'No More Heroes',
        },
    ],
    /* eslint-disable no-template-curly-in-string */
    slotDefault: '<div header="band">Name: ${band}</div>\n' +
        '<div column="band">Name: ${band}</div>',
    /* eslint-enable no-template-curly-in-string */
}

export const DataViaSlot = Template.bind({})
DataViaSlot.args = {
    slotDefault: '<c-thead>\n' +
        '    <c-tr>\n' +
        '        <c-th>First Heading</c-th>\n' +
        '        <c-th>Second Heading</c-th>\n' +
        '    </c-tr>\n' +
        '</c-thead>\n' +
        '<c-tbody>\n' +
        '    <c-tr>\n' +
        '        <c-td>Some data in the first column.</c-td>\n' +
        '        <c-td>Some data in the second column.</c-td>\n' +
        '    </c-tr>\n' +
        '    <c-tr>\n' +
        '        <c-td>And some more data in the first column.</c-td>\n' +
        '        <c-td>And some more data in the second column.</c-td>\n' +
        '    </c-tr>\n' +
        '</c-tbody>',
}
