 
export default {
    argTypes: {
        error: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        flags: {
            control: 'inline-check',
            options: ['disabled', 'required'],
            table: {
                category: 'attributes',
            },
        },
        formSkin: {
            control: 'inline-radio',
            mapping: {
                default: '',
            },
            options: ['underline', 'bordered', 'default'],
            table: {
                category: 'attributes',
            },
        },
        help: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        label: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        labelPosition: {
            control: 'inline-radio',
            mapping: {
                default: '',
            },
            options: ['default', 'left', 'inside'],
            table: {
                category: 'attributes',
            },
        },
        placeholder: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        slotHelp: {
            control: 'text',
            table: {
                category: 'text',
            },
        },
        value: {
            control: 'text',
            table: {
                category: 'data',
            },
        },
    },
    parameters: {
        layout: 'padded',
    },
    tags: ['autodocs'],
    title: 'Composed Components/Forms/Textarea',
}

// eslint-disable-next-line max-statements
const Template = ({ ...args }) => {
    const template = document.createElement('c-textarea')

   if (args.flags) {
        for (const flag of args.flags)
            template.setAttribute(flag, '')
   }

   if (args.labelPosition)
       template.setAttribute('label-position', args.labelPosition)
   if (args.formSkin)
       template.setAttribute('form-skin', args.formSkin)

   for (const [key, value] of Object.entries(args)) {
       if (value)
           template.setAttribute(key, value)
   }

   if (args.slotHelp) {
        const range = document.createRange()
        const fragment = range.createContextualFragment(args.slotHelp)
        const helpSlot = document.createElement('div')
        helpSlot.setAttribute('slot', 'help')
        helpSlot.append(...fragment.childNodes)
        template.appendChild(helpSlot)
    }

   return template
}

export const Default = Template.bind({})
Default.args = {
    flags: 'required',
    help: 'Some help text.',
    label: 'I am the label',
    placeholder: 'I am the placeholder',
    slotHelp: '<span>I am a <strong>slotted</strong> <c-link>help text</c-link>.</span>',
}

export const Disabled = Template.bind({})
Disabled.args = {
    flags: 'disabled',
    label: 'I am a verbose label i want to talk, talk, talk but i have nothing to say.',
    labelPosition: 'left',
    value: 'I am disabled.',
}

export const WithError = Template.bind({})
WithError.args = {
    ...Default.args,
    error: 'Please review your input.',
    labelPosition: 'inside',
}

 
