/**
 * The Translucent script element.
 *
 * @return  {HTMLElement}   The translucent script element
 */

export const scriptElement = document.querySelector('script[src*="translucent.js"]')

/**
 * A function to run arbitrary JavaScript code in a clean context / scope.
 *
 * This is basically an ``eval()`` function on steroids. While ``eval()`` works
 * and looks alright out of the box, you always have one big issue - the scope.
 * The ``eval()`` function will always run in the current scope where it's
 * called, thus evaluating the arbitrary JavaScript code, can have side effects
 * for the scope ``eval()`` is currently run in.
 *
 * This function will avoid those side effects, by simply running the arbitrary
 * JavaScript :js:attr:`code` in a new anonymous function. Since the code might
 * require some :js:attr:`context` (vars), it will be passed to the function as
 * well.
 *
 * @param   {String} code       The arbitrary JavaScript code to run
 * @param   {Object} context    The context (vars) for the code
 *
 * @return                          The return value of the evaluated code
 */

export const cleanContextEval = (code, context) => new Function(  // eslint-disable-line no-new-func
    ...Object.keys(context),    // Function arguments
    code,                       // Function body
)(...Object.values(context))    // Call w/ arguments

/**
 * Get the path to a Translucent file or directory relative to the included
 * translucent script path. The returned path can be used to include additional
 * translucent resources.
 *
 * @param   {String} path   A file or directory name within translucent
 *
 * @return  {String}        The path of the file or directory
 */

export const getPath = path => scriptElement.getAttribute('src').replace('translucent.js', path)
